/*
 *
 * Perforce/JBuilder Opentool
 * Copyright (C) 2002 Mark Ackerman
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation;
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package com.dafreels.opentools.actions;

//JBuilder
import java.awt.Cursor;

import com.borland.primetime.editor.EditorAction;
import com.borland.primetime.editor.EditorPane;
import com.borland.primetime.ide.Browser;
import com.borland.primetime.ide.BrowserAction;
import com.dafreels.opentools.Main;
import com.dafreels.opentools.MessageWriter;
import com.dafreels.opentools.actions.ui.SubmittedChangeListDialog;
import com.dafreels.vcs.command.CommandTool;
import com.dafreels.vcs.command.MessageFormatter;
import com.dafreels.vcs.util.ActionImages;

/**
 * Title: Perforce OpenTool
 * Description: Action to display the ChangeList Dialog
 * Copyright:    Copyright (c) 2002
 * Company:
 * @author Mark Ackerman
 * @version 1.0
 */

public class SubmittedAction extends BrowserAction {
  private SubmittedChangeListDialog _dialog;

  public SubmittedAction() {
    super("Submitted ChangeLists");
    setLongText("View Submitted ChangeLists");
    super.setSmallIcon(ActionImages.P4_SUBMITTED_CHANGELIST);
  }

  public void actionPerformed(Browser browser) {
    Cursor savedEditorCursor = null;
    EditorPane editor = null;
    try {
      editor = EditorAction.getFocusedEditor();
      Cursor waitCursor = Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR);
      if (editor != null) {
        savedEditorCursor = editor.getCursor();
        editor.setCursor(waitCursor);
      }
      browser.setCursor(waitCursor);
      com.dafreels.vcs.command.Command cmd =
        new com.dafreels.vcs.command.Command("changes -m 100 -l -s submitted");

      //Run the command
      CommandTool.runCommand(cmd, Main.m_props);

      //Output the p4 messages
      MessageWriter.outputErrorMessages(MessageFormatter.getInstance());
      if (_dialog == null) {
        _dialog =
          new SubmittedChangeListDialog(Browser.getActiveBrowser(), false);
      }
      _dialog.fillForm(MessageFormatter.getInstance());
      _dialog.setVisible(true);
    }
    finally {
      browser.setCursor(Cursor.getDefaultCursor());
      if (editor != null && savedEditorCursor != null) {
        editor.setCursor(savedEditorCursor);
      }
    }
  }

}
